==> kilroy-face-twitter-0.2.1.tar.gz: kilroy-face-twitter-0.2.1/src/kilroy_face_twitter/scorers.py <==
from abc import ABC, abstractmethod
from dataclasses import dataclass
from typing import Generic, Iterable

from kilroy_face_server_py_sdk import (
    BaseState,
    Categorizable,
    ConfigurableWithLoadableState,
    Parameter,
    StateType,
)
from tweepy import Tweet

from kilroy_face_twitter.client import TwitterClient
from kilroy_face_twitter.models import TweetFields, TweetIncludes


class Scorer(
    ConfigurableWithLoadableState[StateType],
    Categorizable,
    Generic[StateType],
    ABC,
):
    @abstractmethod
    async def score(
        self, client: TwitterClient, tweet: Tweet, includes: TweetIncludes
    ) -> float:
        pass

    @staticmethod
    @abstractmethod
    def needed_fields() -> TweetFields:
        pass


# Likes


@dataclass
class LikesScorerState(BaseState):
    pass


class LikesScorer(Scorer[LikesScorerState]):
    @classmethod
    def category(cls) -> str:
        return "likes"

    async def score(
        self, client: TwitterClient, tweet: Tweet, includes: TweetIncludes
    ) -> float:
        return tweet.public_metrics["like_count"]

    @staticmethod
    def needed_fields() -> TweetFields:
        return TweetFields(tweet_fields=["public_metrics"])

    async def _create_initial_state(self) -> LikesScorerState:
        return LikesScorerState()

    async def _get_parameters(self) -> Iterable[Parameter]:
        return []


# Retweets


@dataclass
class RetweetsScorerState(BaseState):
    pass


class RetweetsScorer(Scorer[RetweetsScorerState]):
    @classmethod
    def category(cls) -> str:
        return "retweets"

    async def score(
        self, client: TwitterClient, tweet: Tweet, includes: TweetIncludes
    ) -> float:
        return tweet.public_metrics["retweet_count"]

    @staticmethod
    def needed_fields() -> TweetFields:
        return TweetFields(tweet_fields=["public_metrics"])

    async def _create_initial_state(self) -> RetweetsScorerState:
        return RetweetsScorerState()

    async def _get_parameters(self) -> Iterable[Parameter]:
        return []


# Impressions


@dataclass
class ImpressionsScorerState(BaseState):
    pass


class ImpressionsScorer(Scorer[ImpressionsScorerState]):
    @classmethod
    def category(cls) -> str:
        return "impressions"

    async def score(
        self, client: TwitterClient, tweet: Tweet, includes: TweetIncludes
    ) -> float:
        return tweet.non_public_metrics["impression_count"]

    @staticmethod
    def needed_fields() -> TweetFields:
        return TweetFields(tweet_fields=["non_public_metrics"])

    async def _create_initial_state(self) -> ImpressionsScorerState:
        return ImpressionsScorerState()

    async def _get_parameters(self) -> Iterable[Parameter]:
        return []

==> kilroy-face-twitter-0.4.0.tar.gz: kilroy-face-twitter-0.4.0/src/kilroy_face_twitter/scorers.py <==
from abc import ABC, abstractmethod

from kilroy_face_server_py_sdk import Categorizable, classproperty, normalize
from tweepy import Tweet

from kilroy_face_twitter.client import TwitterClient
from kilroy_face_twitter.models import TweetFields, TweetIncludes


class Scorer(Categorizable, ABC):
    @classproperty
    def category(cls) -> str:
        name: str = cls.__name__
        return normalize(name.removesuffix("Scorer"))

    @abstractmethod
    async def score(
        self, client: TwitterClient, tweet: Tweet, includes: TweetIncludes
    ) -> float:
        pass

    @classproperty
    @abstractmethod
    def needed_fields(cls) -> TweetFields:
        pass


# Likes


class LikesScorer(Scorer):
    async def score(
        self, client: TwitterClient, tweet: Tweet, includes: TweetIncludes
    ) -> float:
        return tweet.public_metrics["like_count"]

    @classproperty
    def needed_fields(cls) -> TweetFields:
        return TweetFields(tweet_fields=["public_metrics"])


# Retweets


class RetweetsScorer(Scorer):
    async def score(
        self, client: TwitterClient, tweet: Tweet, includes: TweetIncludes
    ) -> float:
        return tweet.public_metrics["retweet_count"]

    @classproperty
    def needed_fields(cls) -> TweetFields:
        return TweetFields(tweet_fields=["public_metrics"])


# Impressions


class ImpressionsScorer(Scorer):
    async def score(
        self, client: TwitterClient, tweet: Tweet, includes: TweetIncludes
    ) -> float:
        return tweet.non_public_metrics["impression_count"]

    @classproperty
    def needed_fields(cls) -> TweetFields:
        return TweetFields(tweet_fields=["non_public_metrics"])
